@@ -25,11 +25,14 @@ import warnings
 from extras import (
     safe_hasattr,
     try_import,
-    try_imports,
     )
-fixtures = try_import('fixtures')
 # To let setup.py work, make this a conditional import.
-unittest = try_imports(['unittest2', 'unittest'])
+# Don't use extras.try_imports, as it interferes with PyCharm's unittest
+# detection algorithm. See: https://youtrack.jetbrains.com/issue/PY-26630
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
 import six
 
 from testtools import (
@@ -83,7 +86,7 @@ _UnexpectedSuccess = try_import(
 
 
 class _ExpectedFailure(Exception):
-    """An expected failure occured.
+    """An expected failure occurred.
 
     Note that this exception is private plumbing in testtools' testcase
     module.
@@ -184,6 +187,12 @@ def gather_details(source_dict, target_dict):
         target_dict[name] = _copy_content(content_object)
 
 
+# Circular import: fixtures imports gather_details from here, we import
+# fixtures, leading to gather_details not being available and fixtures being
+# unable to import it.
+fixtures = try_import('fixtures')
+
+
 def _mods(i, mod):
     (q, r) = divmod(i, mod)
     while True:
@@ -386,7 +395,7 @@ class TestCase(unittest.TestCase):
         the exception has caused.
 
         Handlers are called in first-added, first-called order, and if they
-        raise an exception, that will propogate out of the test running
+        raise an exception, that will propagate out of the test running
         machinery, halting test processing. As a result, do not call code that
         may unreasonably fail.
         """
